shithub: pokecrystal

Download patch

ref: cfd432f468962a2f67a492afbc5203546117544a
parent: cf1c50555505f525ede5e2cd426f002312038de0
author: mid-kid <esteve.varela@gmail.com>
date: Wed Mar 8 08:51:04 EST 2023

Minor battle tower fixes

--- a/data/battle_tower/unknown_levels.asm
+++ b/data/battle_tower/unknown_levels.asm
@@ -13,6 +13,7 @@
 	db $27
 	db $42
 	db $24
+.end
 
 Unknown_17047e:
 	db $03,  4
--- a/engine/events/battle_tower/battle_tower.asm
+++ b/engine/events/battle_tower/battle_tower.asm
@@ -497,7 +497,7 @@
 	ld a, [hli]
 	and a
 	jr z, .empty
-	cp 15
+	cp (Unknown_170470.end - Unknown_170470) + 1
 	jr nc, .copy_data
 
 	push hl
@@ -510,7 +510,7 @@
 	pop hl
 
 	; If Unknown_170470[a-1] <= b, overwrite the current trainer's data
 	; with Unknown17047e, and exit the inner loop.
 	cp b
 	jr c, .copy_data
 	jr z, .copy_data
@@ -518,9 +518,9 @@
 
 .empty
 	; If a == 0 and b >= $fc, overwrite the current trainer's data with
 	; Unknown17047e, and exit the inner loop.
 	ld a, b
-	cp $fc
+	cp NUM_POKEMON + 1
 	jr nc, .copy_data
 
 .next_iteration
@@ -510,7 +510,7 @@
 
 	; If Unknown_170470[a-1] <= b, overwrite the current trainer's data
-	; with Unknown17047e, and exit the inner loop.
+	; with Unknown_17047e, and exit the inner loop.
 	cp b
 	jr c, .copy_data
@@ -518,9 +518,9 @@
 .empty
 	; If a == 0 and b >= $fc, overwrite the current trainer's data with
-	; Unknown17047e, and exit the inner loop.
+	; Unknown_17047e, and exit the inner loop.
 	ld a, b